﻿using System;
using System.Net;
using System.Web.Http;
using System.Web.Mvc;
using Kreta.BusinessLogic.HelperClasses;
using Kreta.BusinessLogic.Helpers;
using Kreta.BusinessLogic.Security;
using Kreta.Core.Exceptions;
using Kreta.Resources;
using Kreta.Web.Areas.Tanulo.Models;
using Kreta.Web.Helpers;
using Kreta.Web.Helpers.Error;
using Kreta.Web.Models.EditorTemplates;
using Kreta.Web.Security;

namespace Kreta.Web.Areas.Tanulo.Controllers
{
    [MvcRoleClaimsAuthorize(true)]
    [MvcRolePackageDenyAuthorize(KretaClaimPackages.IsOnlyAlkalmozott.ClaimValue)]
    [MvcRolePackageAuthorize(KretaClaimPackages.Osztalyfonok.ClaimValue, KretaClaimPackages.SzuperOsztalyfonok.ClaimValue, KretaClaimPackages.Evfolyamfelelos.ClaimValue)]
    public class OsztalyTanuloiGondviselokController : Controller
    {
        public ActionResult Index()
        {
            var model = new OsztalyTanuloiGondviselokSearchModel();
            return View("Index", model);
        }


        public ActionResult OpenGondviseloInfoPopUp(int gondviseloId)
        {
            try
            {
                var gondviseloInfoModel = new OsztalyTanuloiGondviselokPopupModel(new TanuloHelper(ConnectionTypeExtensions.GetSessionConnectionType()).GetGondviseloInfoPopUp(gondviseloId));

                var model = new PopUpModel(gondviseloInfoModel, "Info_PopUp");

                model.AddCancelBtn(model, "OsztalyTanuloiGondviselokHelper.gondviseloInfoCancel");

                return PartialView(Constants.General.PopupView, model);
            }
            catch (BlException ex)
            {
                throw new StatusError(HttpStatusCode.BadRequest, ex.Message);
            }
        }

        public ActionResult ExportOsztalyTanulokGondviseloi([FromUri] OsztalyTanuloiGondviselokSearchModel model)
        {
            var stream = new TanuloHelper(ConnectionTypeExtensions.GetSessionConnectionType()).GetOsztalyTanulokGondviseloiExcelExport(model.ConvertToCo(), ClaimData.IsSzuperOsztalyfonok, ClaimData.FelhasznaloSzerepCsomagok.Contains(KretaClaimPackages.Evfolyamfelelos.ClaimValue));
            return new FileStreamResult(stream, Core.Constants.ContentTypes.Xlsx) { FileDownloadName = $"{TanuloResource.OsztalyTanulokGondviseloiExportFileName}_{DateTime.Now.ToString(Core.Constants.ToStringPattern.HungarianDateExportPattern)}{Core.Constants.ImportExport.FileExtensionExcelX}" };
        }
    }
}
