﻿using System;
using System.Collections.Generic;
using System.Web.Mvc;
using Kreta.BusinessLogic.Classes;
using Kreta.BusinessLogic.Helpers;
using Kreta.BusinessLogic.Security;
using Kreta.Enums;
using Kreta.Enums.ManualEnums;
using Kreta.Web.Areas.Tanulo.Models;
using Kreta.Web.Helpers;
using Kreta.Web.Models.EditorTemplates;
using Kreta.Web.Security;

namespace Kreta.Web.Areas.Tanulo.Controllers
{
    [MvcRoleClaimsAuthorize(true)]
    [MvcRolePackageDenyAuthorize(KretaClaimPackages.IsOnlyAlkalmozott.ClaimValue)]
    [MvcRolePackageAuthorize(KretaClaimPackages.Adminisztrator.ClaimValue)]
    public class SzakkepzesiJuttatasokController : Controller
    {
        // GET: Tanulo/SzakkepzesiJuttatasok
        public ActionResult Index()
        {
            return View();
        }

        public ActionResult OpenSelectorPopup()
        {
            var model = new SzakkepzesiJuttatasokSelectorPopupModel
            {
                IsApaczaiEnabled = new IntezmenyConfigHelper(ConnectionTypeExtensions.GetSystemConnectionType()).GetIntezmenyConfig<bool>(IntezmenyConfigModulEnum.Apaczai, IntezmenyConfigTipusEnum.IsEnabled)
            };
            var popupModel = new PopUpModel(model, "SelectorPopup");
            return PartialView(Constants.General.PopupView, popupModel);
        }

        public ActionResult LoadSzakkepzesiOsztondijSearchPanelView()
        {
            var model = new TanuloSzakkepzesiOsztondijSearchModel() { TanuloTipus = 1 };
            return PartialView("SzakkepzesiOsztondijSearchPanel", model);
        }

        public ActionResult LoadSzakkepzesiOsztondijView()
        {
            var intezmenyAdatok = new IntezmenyHelper(ConnectionTypeExtensions.GetActiveSessionConnectionType()).GetIntezmenyiAdatok();
            var tanevCo = new TanevHelper(ConnectionTypeExtensions.GetActiveSessionConnectionType()).GetTanevInfo();
            DateTime vizsgaltHonap = TanuloHelper.GetJuttatasVizsgaltHonap(tanevCo, intezmenyAdatok.JuttatasHatarnap, DateTime.Today);
            var model = new TanuloSzakkepzesiOsztondijSearchModel();
            model.VizsgaltHonap = string.Format("{0}. {1} ", vizsgaltHonap.Year, ((HonapokEnum.Januar + (vizsgaltHonap.Month - 1))).GetDisplayName(ClaimData.SelectedTanevID.Value).ToLower());
            return PartialView("SzakkepzesiOsztondij", model);
        }

        public ActionResult LoadEgyszeriPalyakezdesiJuttatasSearchPanelView()
        {
            var model = new TanuloEgyszeriPalyakezdesiJuttatasSearchModel();
            return PartialView("EgyszeriPalyakezdesiJuttatasSearchPanel", model);
        }

        public ActionResult LoadEgyszeriPalyakezdesiJuttatasView()
        {
            return PartialView("EgyszeriPalyakezdesiJuttatas");
        }

        public ActionResult LoadApaczaiOsztondijView()
        {
            var model = new ApaczaiTablazatModel
            {
                TipusList = GetApaczaiOsztondijTablazatList(),
                TipusId = (int)ApaczaiOsztondijTablazatEnum.Igenylesek
            };
            return PartialView("ApaczaiOsztondijContainer", model);
        }

        [MvcRolePackageDenyAuthorize(KretaClaimPackages.Adminisztrator.ClaimValue)]
        public List<SelectListItem> GetApaczaiOsztondijTablazatList()
        {
            var dictionary = EnumExtensions.EnumToDictionary<ApaczaiOsztondijTablazatEnum>(ClaimData.SelectedTanevID.Value, removeValueList: new List<string> { ((int)ApaczaiOsztondijTablazatEnum.Kifizetesek).ToString() });
            var result = new List<SelectListItem>();

            foreach (var x in dictionary)
            {
                var sli = new SelectListItem { Text = x.Value, Value = x.Key };
                result.Add(sli);
            }

            return result;
        }

        public ActionResult LoadApaczaiIgenylesekSearchPanelView()
        {
            var model = new TanuloApaczaiOsztondijIgenylesekSearchModel();
            return PartialView("ApaczaiIgenylesekSearchPanel", model);
        }

        public ActionResult LoadApaczaiIgenylesekView()
        {
            return PartialView("ApaczaiIgenylesek");
        }

        public ActionResult LoadApaczaiTanuloiListaSearchPanelView()
        {
            var model = new TanuloApaczaiOsztondijTanuloiListaSearchModel();
            return PartialView("ApaczaiTanuloiListaSearchPanel", model);
        }

        public ActionResult LoadApaczaiTanuloiListaView()
        {
            var intezmenyAdatok = new IntezmenyHelper(ConnectionTypeExtensions.GetActiveSessionConnectionType()).GetIntezmenyiAdatok();
            var tanevCo = new TanevHelper(ConnectionTypeExtensions.GetActiveSessionConnectionType()).GetTanevInfo();
            DateTime vizsgaltHonap = TanuloHelper.GetJuttatasVizsgaltHonap(tanevCo, intezmenyAdatok.JuttatasHatarnap, DateTime.Today);
            var model = new TanuloApaczaiOsztondijTanuloiListaSearchModel
            {
                VizsgaltHonap = string.Format("{0}. {1} ", vizsgaltHonap.Year, (HonapokEnum.Januar + (vizsgaltHonap.Month - 1)).GetDisplayName(ClaimData.SelectedTanevID.Value).ToLower()),
            };
            return PartialView("ApaczaiTanuloiLista", model);
        }

        [MvcRolePackageDenyAuthorize(KretaClaimPackages.Adminisztrator.ClaimValue)]
        public ActionResult LoadApaczaiKifizetesekSearchPanelView()
        {
            var model = new TanuloApaczaiOsztondijKifizetesekSearchModel();
            return PartialView("ApaczaiKifizetesekSearchPanel", model);
        }

        [MvcRolePackageDenyAuthorize(KretaClaimPackages.Adminisztrator.ClaimValue)]
        public ActionResult LoadApaczaiKifizetesekView()
        {
            return PartialView("ApaczaiKifizetesek");
        }
    }
}
