﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Net.Mime;
using System.Text;
using System.Web;
using System.Web.Http;
using System.Web.Mvc;
using Kreta.BusinessLogic.Classes;
using Kreta.BusinessLogic.HelperClasses;
using Kreta.BusinessLogic.Helpers;
using Kreta.BusinessLogic.Helpers.SystemSettings;
using Kreta.BusinessLogic.Security;
using Kreta.Core;
using Kreta.Enums;
using Kreta.Enums.ManualEnums;
using Kreta.Resources;
using Kreta.Web.Areas.Tanulo.Helper;
using Kreta.Web.Areas.Tanulo.Models;
using Kreta.Web.Areas.TanuloErtekeles.Controllers;
using Kreta.Web.Helpers;
using Kreta.Web.Helpers.Error;
using Kreta.Web.Helpers.Modal;
using Kreta.Web.Models;
using Kreta.Web.Models.EditorTemplates;
using Kreta.Web.Security;

namespace Kreta.Web.Areas.Tanulo.Controllers
{
    [MvcRoleClaimsAuthorize(true)]
    [MvcRolePackageDenyAuthorize(KretaClaimPackages.IsOnlyAlkalmozott.ClaimValue)]
    [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.Osztalyfonok.ClaimValue)]
    public class TanuloController : BaseTanuloController
    {
        [MvcRolePackageDenyAuthorize(TanevEnum.Mind, KretaClaimPackages.Osztalyfonok.ClaimValue)]
        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.Osztalyfonok.ClaimValue, KretaClaimPackages.IsLEPKezelo.ClaimValue)]
        public ActionResult Index(string filter)
        {
            if (ClaimData.IsCsokkentettTanuloLEP)
            {
                return View("IndexLEP", new TanuloSearchModel());
            }

            var model = TanuloSearchModel.SetFilterTanuloSearchModel(filter);
            model.FeladatEllatasiHelyId = ClaimData.FelhelySzuro;
            TanuloLogic.SetButtonVisibility(model);

            return View("Index", model);
        }

        [MvcRolePackageDenyAuthorize(TanevEnum.Mind, KretaClaimPackages.Osztalyfonok.ClaimValue)]
        [System.Web.Mvc.ActionName("AktivTanulok")]
        public ActionResult Index()
        {
            var model = new TanuloSearchModel
            {
                FeladatKategoriaId = Constants.MindenErteke.FeladatKategoria,
                Aktiv = true
            };

            TanuloLogic.SetButtonVisibility(model);

            return View("Index", model);
        }

        [MvcRolePackageDenyAuthorize(TanevEnum.Mind, KretaClaimPackages.Osztalyfonok.ClaimValue)]
        [System.Web.Mvc.ActionName("AktivTanulokByOsztaly")]
        public ActionResult Index(int osztalyId)
        {
            var model = new TanuloSearchModel
            {
                FeladatKategoriaId = Constants.MindenErteke.FeladatKategoria,
                Aktiv = true,
                OsztalyCsoportId = osztalyId
            };

            TanuloLogic.SetButtonVisibility(model);

            return View("Index", model);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.FelhasznaloMunkakoreNemTiltoListas.ClaimValue, KretaClaimPackages.Osztalyfonok.ClaimValue, KretaClaimPackages.SzuperOsztalyfonok.ClaimValue, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.CsoportVezeto.ClaimValue, KretaClaimPackages.Evfolyamfelelos.ClaimValue, KretaClaimPackages.Dualis_Admin.ClaimValue, KretaClaimPackages.IsSzakiranyuOktatasertFelelos.ClaimValue)]
        public ActionResult GetPartialView(string id, string partialViewName, string IsFromSzervezet = null)
        {
            var isFromSzervezet = SDAConvert.ToBoolean(IsFromSzervezet);
            var model = AlapkepzesTanuloLogic.GetTanuloData(int.Parse(id));
            model.TanuloApiControllerName = isFromSzervezet ? Constants.ApiControllers.DualisTanuloApi : Constants.ApiControllers.TanuloApi;
            model.IsFromSzervezet = isFromSzervezet;
            return PartialView(partialViewName, model);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.FelhasznaloMunkakoreNemTiltoListas.ClaimValue, KretaClaimPackages.Osztalyfonok.ClaimValue, KretaClaimPackages.SzuperOsztalyfonok.ClaimValue, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.CsoportVezeto.ClaimValue, KretaClaimPackages.Evfolyamfelelos.ClaimValue, KretaClaimPackages.Dualis_Admin.ClaimValue, KretaClaimPackages.IsSzakiranyuOktatasertFelelos.ClaimValue)]
        public ActionResult GetSzakkepzesiJuttatasokPartialView(string id, string osztalyCsoportIdString, string partialViewName)
        {
            int? osztalyCsoportId = null;
            if (int.TryParse(osztalyCsoportIdString, out var resultId))
            { osztalyCsoportId = resultId; }

            var tanuloModel = AlapkepzesTanuloLogic.GetTanuloData(int.Parse(id), osztalyCsoportId);

            var model = new SzakkepzesiJuttatasokModel
            {
                TanuloiOsztondijPanelBar = new TanuloiOsztondijPanelBarModel
                {
                    Animation = true,
                    ChildModels = new List<PanelBarChildModel>
                    {
                        new PanelBarChildModel
                        {
                            PartialViewTitle = TanuloResource.TanuloOsztondijAdatai,
                            PartialViewName = "TanuloiOsztondijInfoPanelBar",
                            Data = new List<object> { tanuloModel },
                        }
                    },
                    ExpandMode = Kendo.Mvc.UI.PanelBarExpandMode.Multiple,
                    PanelName = "TanuloiOsztondijPanel",
                },
                EgyszeriPayakezdesiPanelBar = new EgyszeriPalyakezdesiPanelBarModel
                {
                    Animation = true,
                    ChildModels = new List<PanelBarChildModel>
                    {
                        new PanelBarChildModel
                        {
                            PartialViewTitle = TanuloResource.EgyszeriPalyakezdesiJuttatas,
                            PartialViewName = "EgyszeriPalyakezdesiPanelBar",
                            Data = new List<object> { tanuloModel.TanuloEgyszeriPalyakezdesiModel },
                        }
                    },
                    ExpandMode = Kendo.Mvc.UI.PanelBarExpandMode.Multiple,
                    PanelName = "EgyszeriPalyakezdesiPanel",
                },
                ApaczaiOsztondijPanelBar = new ApaczaiOsztondijPanelBarModel
                {
                    Animation = true,
                    ChildModels = new List<PanelBarChildModel>
                    {
                        new PanelBarChildModel
                        {
                            PartialViewTitle = TanuloResource.ApaczaiOsztondijAdatai,
                            PartialViewName = "ApaczaiOsztondijInfoPanelBar",
                            Data = new List<object> { tanuloModel },
                        }
                    },
                    ExpandMode = Kendo.Mvc.UI.PanelBarExpandMode.Multiple,
                    PanelName = "ApaczaiOsztondijPanel",
                },
            };

            return PartialView(partialViewName, model);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.FelhasznaloMunkakoreNemTiltoListas.ClaimValue, KretaClaimPackages.Osztalyfonok.ClaimValue, KretaClaimPackages.SzuperOsztalyfonok.ClaimValue, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.CsoportVezeto.ClaimValue, KretaClaimPackages.Evfolyamfelelos.ClaimValue)]
        public ActionResult GetModPartialView(string id, string partialViewName)
        {
            var model = AlapkepzesTanuloLogic.GetModTanuloData(int.Parse(id));
            return PartialView(partialViewName, model);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Tanar.ClaimValue, KretaClaimPackages.Osztalyfonok.ClaimValue, KretaClaimPackages.SzuperOsztalyfonok.ClaimValue, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.CsoportVezeto.ClaimValue, KretaClaimPackages.Evfolyamfelelos.ClaimValue, KretaClaimPackages.Dualis_Admin.ClaimValue, KretaClaimPackages.IsSzakiranyuOktatasertFelelos.ClaimValue)]
        public ActionResult GetPartialViewWithOsztalycsoport(string id, string osztalyCsoportIdString, string partialViewName)
        {
            int? osztalyCsoportId = null;
            if (int.TryParse(osztalyCsoportIdString, out var resultId))
            { osztalyCsoportId = resultId; }

            var model = AlapkepzesTanuloLogic.GetTanuloData(int.Parse(id), osztalyCsoportId);
            return PartialView(partialViewName, model);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Tanar.ClaimValue, KretaClaimPackages.Osztalyfonok.ClaimValue, KretaClaimPackages.SzuperOsztalyfonok.ClaimValue, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.CsoportVezeto.ClaimValue, KretaClaimPackages.Evfolyamfelelos.ClaimValue)]
        public ActionResult GetModPartialViewWithOsztalycsoport(string id, string osztalyCsoportIdString, string partialViewName)
        {
            int? osztalyCsoportId = null;
            if (int.TryParse(osztalyCsoportIdString, out int resultId))
            { osztalyCsoportId = resultId; }

            var model = AlapkepzesTanuloLogic.GetModTanuloData(int.Parse(id), osztalyCsoportId);
            var osztalyJellemzok = new FeladatEllatasiHelyHelper(ConnectionTypeExtensions.GetSessionConnectionType()).GetOsztalyJellemzoi(osztalyId: osztalyCsoportId);
            model.TanuloTanugyModel.IsSzakkepzeses = osztalyJellemzok[OsztalyJellemzoEnum.IsSzakkepzeses];
            model.IsDualisKepzesEnabled = new IntezmenyConfigHelper(ConnectionTypeExtensions.GetSystemConnectionType()).GetIntezmenyConfig<bool>(IntezmenyConfigModulEnum.DualisKepzes, IntezmenyConfigTipusEnum.IsEnabled);
            return PartialView(partialViewName, model);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Tanar.ClaimValue, KretaClaimPackages.Osztalyfonok.ClaimValue, KretaClaimPackages.SzuperOsztalyfonok.ClaimValue, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.CsoportVezeto.ClaimValue, KretaClaimPackages.Evfolyamfelelos.ClaimValue)]
        public ActionResult GetModSzakkepzesiJuttatasokPartialViewWithOsztalycsoport(string id, string osztalyCsoportIdString, string partialViewName)
        {
            int? osztalyCsoportId = null;
            if (int.TryParse(osztalyCsoportIdString, out int resultId))
            { osztalyCsoportId = resultId; }

            var tanuloModel = AlapkepzesTanuloLogic.GetModTanuloData(int.Parse(id), osztalyCsoportId);

            var model = new SzakkepzesiJuttatasokModel
            {
                TanuloiOsztondijPanelBar = new TanuloiOsztondijPanelBarModel
                {
                    Animation = true,
                    ChildModels = new List<PanelBarChildModel>
                    {
                        new PanelBarChildModel
                        {
                            PartialViewTitle = TanuloResource.TanuloOsztondijAdatai,
                            PartialViewName = "TanuloiOsztondijPanelBar",
                            Data = new List<object> { tanuloModel },
                        }
                    },
                    ExpandMode = Kendo.Mvc.UI.PanelBarExpandMode.Multiple,
                    PanelName = "TanuloiOsztondijPanel",
                },
                EgyszeriPayakezdesiPanelBar = new EgyszeriPalyakezdesiPanelBarModel
                {
                    Animation = true,
                    ChildModels = new List<PanelBarChildModel>
                    {
                        new PanelBarChildModel
                        {
                            PartialViewTitle = TanuloResource.EgyszeriPalyakezdesiJuttatas,
                            PartialViewName = "EgyszeriPalyakezdesiPanelBar",
                            Data = new List<object> { tanuloModel.TanuloEgyszeriPalyakezdesiModel },
                        }
                    },
                    ExpandMode = Kendo.Mvc.UI.PanelBarExpandMode.Multiple,
                    PanelName = "EgyszeriPalyakezdesiPanel",
                },
                ApaczaiOsztondijPanelBar = new ApaczaiOsztondijPanelBarModel
                {
                    Animation = true,
                    ChildModels = new List<PanelBarChildModel>
                    {
                        new PanelBarChildModel
                        {
                            PartialViewTitle = TanuloResource.ApaczaiOsztondijAdatai,
                            PartialViewName = "ApaczaiOsztondijPanelBar",
                            Data = new List<object> { tanuloModel },
                        }
                    },
                    ExpandMode = Kendo.Mvc.UI.PanelBarExpandMode.Multiple,
                    PanelName = "ApaczaiOsztondijPanel",
                },
            };
            return PartialView(partialViewName, model);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.FelhasznaloMunkakoreNemTiltoListas.ClaimValue, KretaClaimPackages.Osztalyfonok.ClaimValue, KretaClaimPackages.SzuperOsztalyfonok.ClaimValue, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.CsoportVezeto.ClaimValue, KretaClaimPackages.Dualis_Admin.ClaimValue, KretaClaimPackages.IsSzakiranyuOktatasertFelelos.ClaimValue)]
        public ActionResult GetTanuloErtekelesPartialView(int tanuloId, string partialViewName, string namePrefix, int? osztalycsoportId = null)
        {
            var oktNevelesiKategoria = OktNevelesiKategoriaEnum.NevelesOktatas;

            if (osztalycsoportId.HasValue)
            {
                var osztalyCsoportHelper = new OsztalyCsoportHelper(ConnectionTypeExtensions.GetSessionConnectionType());
                oktNevelesiKategoria = (OktNevelesiKategoriaEnum)osztalyCsoportHelper.GetOsztalyCsoportFeladatKategoria(osztalycsoportId.Value);
            }

            var tanuloOktatasiNevelesiFeladatIds = new TanuloHelper(ConnectionTypeExtensions.GetSessionConnectionType())
            .GetTanuloOktatasiNevelesiFeladatIdList(tanuloId, oktNevelesiKategoria);

            var model = new TanuloErtekelesByTanuloController().PartialViewModel(tanuloId, namePrefix, tanuloOktatasiNevelesiFeladatIds);
            return PartialView(partialViewName, model);
        }

        #region Popups

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Osztalyfonok.ClaimValue, KretaClaimPackages.SzuperOsztalyfonok.ClaimValue, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.Evfolyamfelelos.ClaimValue, KretaClaimPackages.CsoportVezeto.ClaimValue, KretaClaimPackages.Tanar.ClaimValue, KretaClaimPackages.Dualis_Admin.ClaimValue, KretaClaimPackages.IsSzakiranyuOktatasertFelelos.ClaimValue)]
        public ActionResult OpenDetailTanuloPopUp(int tanuloId, int? osztalycsoportId, bool ertekelesTabAktiv = false, bool tanugyDisabled = false, bool fromAdd = false)
        {
            return OpenDetailTanuloPopUp(tanuloId, osztalycsoportId, false, ertekelesTabAktiv, tanugyDisabled, fromAdd);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Osztalyfonok.ClaimValue, KretaClaimPackages.SzuperOsztalyfonok.ClaimValue, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.Evfolyamfelelos.ClaimValue, KretaClaimPackages.CsoportVezeto.ClaimValue, KretaClaimPackages.FelhasznaloMunkakoreNemTiltoListas.ClaimValue, KretaClaimPackages.Dualis_Admin.ClaimValue, KretaClaimPackages.IsSzakiranyuOktatasertFelelos.ClaimValue)]
        public ActionResult OpenDetailTanitottTanuloPopUp(int tanuloId, bool ertekelesTabAktiv = false, int osztalyCsoportId = -1)
        {
            var tanuloDetailModel = new TanuloDetailModel { TanuloId = tanuloId, OsztalycsoportId = osztalyCsoportId };
            var popUpModel = new PopUpModel(new TanuloSearchModel
            {
                TanuloId = tanuloId,
                TanuloModalHeader = TanuloLogic.GetTanuloModalHeader(tanuloId),
                TabList = TanarTanitottTanulokViewHelper.GetDetailTabs(tanuloDetailModel, ertekelesTabAktiv),
                OsztalyCsoportId = osztalyCsoportId
            }, "Tanulo_Info");

            popUpModel = popUpModel.AddCancelBtn(popUpModel, "TanarTanitottTanulokHelper.detailTanuloCancel");
            return PartialView(Constants.General.PopupView, popUpModel);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Osztalyfonok.ClaimValue, KretaClaimPackages.SzuperOsztalyfonok.ClaimValue, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.Evfolyamfelelos.ClaimValue, KretaClaimPackages.CsoportVezeto.ClaimValue, KretaClaimPackages.Tanar.ClaimValue, KretaClaimPackages.Dualis_Admin.ClaimValue, KretaClaimPackages.IsSzakiranyuOktatasertFelelos.ClaimValue)]
        public ActionResult OpenDetailNemTanitottTanuloPopUp(int tanuloId, bool ertekelesTabAktiv = false, int osztalyCsoportId = -1)
        {
            var tanuloDetailModel = new TanuloDetailModel { TanuloId = tanuloId, OsztalycsoportId = osztalyCsoportId };

            var popUpModel = new PopUpModel(new TanuloSearchModel
            {
                TanuloId = tanuloId,
                TanuloModalHeader = TanuloLogic.GetTanuloModalHeader(tanuloId),
                TabList = TanarTanitottTanulokViewHelper.GetDetailTabs(tanuloDetailModel, ertekelesTabAktiv),
                OsztalyCsoportId = osztalyCsoportId
            }, "Tanulo_Info");

            popUpModel = popUpModel.AddCancelBtn(popUpModel, "TanarNemTanitottTanulokHelper.detailTanuloCancel");
            return PartialView(Constants.General.PopupView, popUpModel);
        }

        public ActionResult OpenNewTanuloPopUp()
        {
            var model = TanuloLogic.CreateNewTanuloPopupModel();
            if (model.TanuloTanugyModel.IsSzakkepzeses)
            {
                TanuloLogic.SetTanuloSzakkepzesesBasicProperties(model);
            }
            TanuloLogic.SetTanuloAmiKepzesiJellemzokProperties(model);
            model.TanuloTanugyModel.HasAktivOsztalybaSorolas = false;
            model.TanuloTanugyModel.TantervId = new TantervHelper(ConnectionTypeExtensions.GetSessionConnectionType()).GetTop1TantervId();
            model.IsDualisKepzesEnabled = new IntezmenyConfigHelper(ConnectionTypeExtensions.GetSystemConnectionType()).GetIntezmenyConfig<bool>(IntezmenyConfigModulEnum.DualisKepzes, IntezmenyConfigTipusEnum.IsEnabled);
            var pm = new PopUpModel(new TanuloModel
            {
                TabList = AlapkepzesTanuloLogic.GetNewTabs(model)
            }, "Tanulo_Bevitel");

            pm = pm.AddCancelBtn(pm, "TanuloHelper.newTanuloCancel");
            pm = pm.AddOkBtn(pm, "TanuloHelper.newTanuloSave");

            return PartialView(Constants.General.PopupView, pm);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.IsLEPKezelo.ClaimValue)]
        public ActionResult OpenLEPTanuloPopUp(int? tanuloId)
        {
            var model = tanuloId.IsEntityId() ?
                new TanuloLEPModel { TanuloId = tanuloId, Nev = new TanuloHelper(ConnectionTypeExtensions.GetSessionConnectionType()).GetTanuloLEP(tanuloId.Value) } :
                new TanuloLEPModel();

            var pm = new PopUpModel(model, "Edit_Tanulo_LEP");

            pm = pm.AddCancelBtn(pm, "TanuloHelper.newTanuloCancel");
            pm = pm.AddOkBtn(pm, "TanuloHelper.newTanuloSave");

            return PartialView(Constants.General.PopupView, pm);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Osztalyfonok.ClaimValue, KretaClaimPackages.SzuperOsztalyfonok.ClaimValue, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.Evfolyamfelelos.ClaimValue)]
        public ActionResult OpenModTanuloPopUp(int tanuloId, int? osztalycsoportId)
        {
            if (osztalycsoportId.HasValue && osztalycsoportId.Value > 0)
            {
                var osztalyCsoportHelper = new OsztalyCsoportHelper(ConnectionTypeExtensions.GetActiveSessionConnectionType());
                if (osztalyCsoportHelper.GetOsztalyCsoportFeladatKategoria(osztalycsoportId.Value) != (int)OktNevelesiKategoriaEnum.NevelesOktatas)
                {
                    var systemSettingsHelper = new SystemSettingsHelper(ConnectionTypeExtensions.GetSessionConnectionType());

                    var gimnaziumAlapkepzeseskentKezelendo = systemSettingsHelper.GetSystemSettingValue<bool>(RendszerBeallitasTipusEnum.Szakgimnaziumok_Alapkezpeseskent_Tudjak_Kezelni_osztalyokat_Tanulokat);
                    if (!(gimnaziumAlapkepzeseskentKezelendo && osztalyCsoportHelper.GetOsztalyCsoportOktatasNevelesiFeladatTipus(osztalycsoportId.Value) == (int)OktatasiNevelesiFeladatEnum.MuveszetiSzakgimnazium))
                    {
                        return OpenDetailTanuloPopUp(tanuloId, osztalycsoportId, fromAdd: true);
                    }
                }
            }

            var tm = AlapkepzesTanuloLogic.GetModTanuloData(tanuloId, osztalycsoportId);
            TanuloLogic.SetTanuloSzakkepzesesBasicProperties(tm);

            tm.TanuloAlapAdatModel.NemList = TanuloLogic.GetNemList(true);
            tm.TanuloAlapAdatModel.FelhasznaloiNevGeneralasModja = TanuloLogic.GetFelhasznaloiNevGeneralasModja(tm);
            tm.TanuloModalHeader = TanuloLogic.GetTanuloModalHeader(tanuloId);

            tm.TabList = AlapkepzesTanuloLogic.GetModTabs(tm, ClaimData.IsOsztalyfonok, osztalycsoportId);

            var pm = new PopUpModel(tm, "Tanulo_Bevitel");
            pm = pm.AddCancelBtn(pm, "TanuloHelper.modTanuloCancel");
            pm = pm.AddOkBtn(pm, "TanuloHelper.modTanuloSave");

            return PartialView(Constants.General.PopupView, pm);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Osztalyfonok.ClaimValue, KretaClaimPackages.SzuperOsztalyfonok.ClaimValue, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.Evfolyamfelelos.ClaimValue)]
        public ActionResult OpenJogviszonySzuneteltetes()
        {
            var pm = new PopUpModel(new JogviszonySzuneteltetesModel(), "Edit_JogviszonySzuneteltetes");
            pm = pm.AddBtn(pm, "JogviszonySzuneteltetesCancel", CommonResource.Megse, "JogviszonySzuneteltetesHelper.Cancel");
            pm = pm.AddBtn(pm, "JogviszonySzuneteltetesSave", CommonResource.Mentes, "JogviszonySzuneteltetesHelper.Save");

            return PartialView(Constants.General.PopupView, pm);
        }

        public ActionResult OpenTobbesModTanuloPopUp(List<TanuloTobbesModAdat> tobbesModAdatList)
        {
            AlapkepzesTanuloLogic.ValidateTobbesModFeladatKategoria(string.Join(", ", tobbesModAdatList.Where(x => x.OsztalyId.HasValue).Select(x => x.OsztalyId.Value)));

            var model = new TanuloTobbesModModel { TanuloTobbesTanugyModel = new TanuloTobbesTanugyModel(), TanuloTobbesJuttatasModel = new TanuloTobbesJuttatasModel() };
            model.IsApaczaiEnabled = new IntezmenyConfigHelper(ConnectionTypeExtensions.GetSystemConnectionType()).GetIntezmenyConfig<bool>(IntezmenyConfigModulEnum.Apaczai, IntezmenyConfigTipusEnum.IsEnabled);
            model.IsDualisKepzesEnabled = new IntezmenyConfigHelper(ConnectionTypeExtensions.GetSystemConnectionType()).GetIntezmenyConfig<bool>(IntezmenyConfigModulEnum.DualisKepzes, IntezmenyConfigTipusEnum.IsEnabled);

            var tanuloHelper = new TanuloHelper(ConnectionTypeExtensions.GetSessionConnectionType());
            model.TanuloTobbesJuttatasModel.IsAgazatiAlapvizsgaTulajdonsagokEnabled = tobbesModAdatList.All(x => tanuloHelper.IsFelevnelValtosByOsztalyAndTanulo(x.OsztalyId.Value, x.TanuloId));
            model.TanuloTobbesJuttatasModel.IsAgazatiAlapvizsgaTulajdonsagokVisible = !tobbesModAdatList.All(x => !tanuloHelper.IsFelevnelValtosByOsztalyAndTanulo(x.OsztalyId.Value, x.TanuloId));
            var helper = new FeladatEllatasiHelyHelper(ConnectionTypeExtensions.GetSessionConnectionType());
            var osztalyJellemzoi = helper.GetOsztalyJellemzoi();
            model.TanuloTobbesTanugyModel.IsSzakkepzeses = osztalyJellemzoi[OsztalyJellemzoEnum.IsSzakkepzeses];
            model.TanuloTobbesTanugyModel.IsNKTSzakkepzeses = osztalyJellemzoi[OsztalyJellemzoEnum.IsNKTSzakkepzeses] && ClaimData.IsSelectedTanev20_21OrLater;
            model.TanuloTobbesTanugyModel.IsSzakkepzo = new IntezmenyHelper(ConnectionTypeExtensions.GetSessionConnectionType()).GetIntezmenyiAdatok().IsSzakkepzo;

            var osztalyIdList = tobbesModAdatList.Where(x => x.OsztalyId.IsEntityId()).Select(x => x.OsztalyId.Value).Distinct().ToList();
            model.TanuloTobbesTanugyModel.IsAllOsztalyAltalanosIskolaFeladatellatasiHely = tanuloHelper.IsAllOsztalyAltalanosIskolaFeladatellatasiHely(osztalyIdList);

            model.TanuloTobbesTanugyModel.HasAktivOsztalybaSorolasGyereknek = tobbesModAdatList.Any(x => x.OsztalyId.IsEntityId());

            model.TabList = AlapkepzesTanuloLogic.GetTanuloTobbesModTabs(model);

            foreach (var item in tobbesModAdatList)
            {
                model.TobbesModIdList.Add(new TanuloTobbesModId() { TanuloId = item.TanuloId, OsztalyId = item.OsztalyId });
            }

            model.TanuloNevArray = string.Join(", ", tobbesModAdatList.Select(x => x.TanuloNev));

            var pm = new PopUpModel(model, "TanuloTobbesModify_Bevitel");
            pm = pm.AddCancelBtn(pm, "TanuloHelper.modifyCancel");
            pm = pm.AddOkBtn(pm, "TanuloHelper.confirmCsopModWindow");

            return PartialView(Constants.General.PopupView, pm);
        }

        public ActionResult NewElerhetosegTel(int tanuloId)
        {
            var model = new CimElerhetosegModel()
            {
                FelhasznaloId = tanuloId,
                TanulovalEgyezik = true,
                AlapertelmezettTel = true,
                TelefonKotelezo = true,
                FormSettings = new List<string>() {
                    CimElerhetosegConstant.TelSectionVisible,
                    CimElerhetosegConstant.IsNew,
                    CimElerhetosegConstant.AlapertelmezettTelVisible
                }
            };

            var tanuloAdatCO = TanuloLogic.GetTanuloAdatCO(tanuloId);
            if (tanuloAdatCO.Telefonszam != null)
            {
                model.AlapertelmezettTel = false;
            }

            model.AlapertelmezettCim = !(new TanuloHelper(ConnectionTypeExtensions.GetSessionConnectionType()).HasTanuloAlapertelmezettTelefon(tanuloId));
            var pm = new PopUpModel(model, "_Elerhetoseg_Tel_Bevitel");

            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnElerhetosegCancel", Text = Resources.CommonResource.Megse, EventName = "TanuloElerhetosegTelHelper.newElerhetosegTelCancel" });
            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnElerhetosegOk", Text = Resources.CommonResource.Mentes, EventName = "TanuloElerhetosegTelHelper.newElerhetosegTelSave" });

            return PartialView(Constants.General.PopupView, pm);
        }

        public ActionResult ModElerhetosegTel(int id)
        {
            var model = TanuloLogic.GetTanuloElerhetosegTel(id);
            model.TanulovalEgyezik = true;
            model.TelefonKotelezo = true;
            model.FormSettings = new List<string>() {
                CimElerhetosegConstant.TelSectionVisible,
                CimElerhetosegConstant.AlapertelmezettTelVisible
            };
            var pm = new PopUpModel(model, "_Elerhetoseg_Tel_Bevitel");

            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnElerhetosegCancel", Text = Resources.CommonResource.Megse, EventName = "TanuloElerhetosegTelHelper.modElerhetosegTelCancel" });
            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnElerhetosegOk", Text = Resources.CommonResource.Mentes, EventName = "TanuloElerhetosegTelHelper.modElerhetosegTelSave" });

            return PartialView(Constants.General.PopupView, pm);
        }

        public ActionResult NewElerhetosegEmail(int tanuloId)
        {
            var model = new CimElerhetosegModel()
            {
                FelhasznaloId = tanuloId,
                AlapertelmezettEmail = true,
                TanulovalEgyezik = true,
                EmailcimKotelezo = true,
                EmailTipusKotelezo = true,
                FormSettings = new List<string>() {
                    CimElerhetosegConstant.EmailSectionVisible,
                    CimElerhetosegConstant.IsNew,
                    CimElerhetosegConstant.AlapertelmezettEmailVisible
                }
            };

            var tanuloAdatCO = TanuloLogic.GetTanuloAdatCO(tanuloId);
            if (tanuloAdatCO.Emailcim != null)
            {
                model.AlapertelmezettEmail = false;
            }

            model.AlapertelmezettCim = !(new TanuloHelper(ConnectionTypeExtensions.GetSessionConnectionType()).HasTanuloAlapertelmezettEmail(tanuloId));
            var pm = new PopUpModel(model, "_Elerhetoseg_Email_Bevitel");

            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnElerhetosegCancel", Text = Resources.CommonResource.Megse, EventName = "TanuloElerhetosegEmailHelper.newElerhetosegEmailCancel" });
            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnElerhetosegOk", Text = Resources.CommonResource.Mentes, EventName = "TanuloElerhetosegEmailHelper.newElerhetosegEmailSave" });

            return PartialView(Constants.General.PopupView, pm);
        }

        public ActionResult ModElerhetosegEmail(int id)
        {
            var model = TanuloLogic.GetTanuloElerhetosegEmail(id);
            model.TanulovalEgyezik = true;
            model.EmailcimKotelezo = true;
            model.EmailTipusKotelezo = true;
            model.FormSettings = new List<string>() {
                CimElerhetosegConstant.EmailSectionVisible,
                CimElerhetosegConstant.AlapertelmezettEmailVisible
            };
            var pm = new PopUpModel(model, "_Elerhetoseg_Email_Bevitel");

            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnElerhetosegCancel", Text = Resources.CommonResource.Megse, EventName = "TanuloElerhetosegEmailHelper.modElerhetosegEmailCancel" });
            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnElerhetosegOk", Text = Resources.CommonResource.Mentes, EventName = "TanuloElerhetosegEmailHelper.modElerhetosegEmailSave" });

            return PartialView(Constants.General.PopupView, pm);
        }

        public ActionResult NewElerhetosegCim(int tanuloId)
        {
            var model = new CimElerhetosegModel()
            {
                FelhasznaloId = tanuloId,
                Orszag = (int)OrszagTipusEnum.Magyarorszag,
                CimTipus = (int)CimTipusEnum.allando_lakcim,
                AlapertelmezettCim = true,
                FormSettings = new List<string>() {
                    CimElerhetosegConstant.CimSectionVisible,
                    CimElerhetosegConstant.AlapertelmezettCimVisible,
                    CimElerhetosegConstant.IsNew
                }
            };
            var hasTanuloAlapertelmezettCim = new TanuloHelper(ConnectionTypeExtensions.GetActiveSessionConnectionType()).HasTanuloAlapertelmezettCim(tanuloId);
            model.AlapertelmezettCim = !hasTanuloAlapertelmezettCim;
            if (!hasTanuloAlapertelmezettCim)
            {
                model.FormSettings.Add(CimElerhetosegConstant.AlapertelmezettNemModosithato);
            }
            var pm = new PopUpModel(model, "_Elerhetoseg_Cim_Bevitel");

            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnElerhetosegCancel", Text = Resources.CommonResource.Megse, EventName = "TanuloElerhetosegCimHelper.newElerhetosegCimCancel" });
            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnElerhetosegOk", Text = Resources.CommonResource.Mentes, EventName = "TanuloElerhetosegCimHelper.newElerhetosegCimSave" });

            return PartialView(Constants.General.PopupView, pm);
        }

        public ActionResult ModElerhetosegCim(int id)
        {
            var model = TanuloLogic.GetTanuloElerhetosegCim(id);
            model.FormSettings = new List<string>(){
                CimElerhetosegConstant.CimSectionVisible,
                CimElerhetosegConstant.AlapertelmezettCimVisible };
            model.IsAlapertelmezettModosithato = !model.AlapertelmezettCim;
            var pm = new PopUpModel(model, "_Elerhetoseg_Cim_Bevitel");

            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnElerhetosegCancel", Text = Resources.CommonResource.Megse, EventName = "TanuloElerhetosegCimHelper.modElerhetosegCimCancel" });
            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnElerhetosegOk", Text = Resources.CommonResource.Mentes, EventName = "TanuloElerhetosegCimHelper.modElerhetosegCimSave" });

            return PartialView(Constants.General.PopupView, pm);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Osztalyfonok.ClaimValue, KretaClaimPackages.SzuperOsztalyfonok.ClaimValue, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.CsoportVezeto.ClaimValue, KretaClaimPackages.Tanar.ClaimValue, KretaClaimPackages.Dualis_Admin.ClaimValue, KretaClaimPackages.IsSzakiranyuOktatasertFelelos.ClaimValue)]
        public ActionResult Info_GondviselokCimGrid(int id)
        {
            return PartialView("Info_GondviselokCimGrid", id);
        }

        public ActionResult NewGondviselo(int tanuloId)
        {
            var model = new TanuloModGondviseloModel()
            {
                TanulovalEgyezik = true,
                GondviseloAutoEmail = !ClaimData.IsSzirIntezmeny,
                FileLetoltesSzukseges = !ClaimData.IsSzirIntezmeny,
                RokonsagiFok = (int)RokonsagiFokEnum.na,
                FelhasznaloId = tanuloId,
                EmailcimKotelezo = false,
                EmailTipusKotelezo = false,
                TelefonKotelezo = false,
                IsGondviseloElerhetoseg = false,
                FormSettings = new List<string>() {
                    CimElerhetosegConstant.EmailSectionVisible,
                    CimElerhetosegConstant.TelSectionVisible,
                    CimElerhetosegConstant.TanuloElerhetosegEmailVisible,
                    CimElerhetosegConstant.TanuloElerhetosegTelVisible
                },
                IsSzirIntezmeny = ClaimData.IsSzirIntezmeny
            };

            var pm = new PopUpModel(model, "_Gondviselo_Bevitel");
            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnGondviseloCancel", Text = Resources.CommonResource.Megse, EventName = "TanuloGondviseloHelper.newGondviseloCancel" });
            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnGondviseloOk", Text = Resources.CommonResource.Mentes, EventName = "TanuloGondviseloHelper.newGondviseloSave" });

            return PartialView(Constants.General.PopupView, pm);
        }

        public ActionResult ModGondviselo(int id)
        {
            var model = TanuloLogic.GetTanuloGondviselo(id);
            model.TanulovalEgyezik = true;
            model.EmailcimKotelezo = false;
            model.EmailTipusKotelezo = false;
            model.TelefonKotelezo = false;
            model.IsGondviseloElerhetoseg = false;
            model.FormSettings = new List<string>() {
                CimElerhetosegConstant.EmailSectionVisible,
                CimElerhetosegConstant.TelSectionVisible,
                CimElerhetosegConstant.TanuloElerhetosegEmailVisible,
                CimElerhetosegConstant.TanuloElerhetosegTelVisible
            };
            model.IsSzirIntezmeny = ClaimData.IsSzirIntezmeny;
            var pm = new PopUpModel(model, "_Gondviselo_Bevitel");

            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnGondviseloCancel", Text = Resources.CommonResource.Megse, EventName = "TanuloGondviseloHelper.modGondviseloCancel" });
            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnGondviseloOk", Text = Resources.CommonResource.Mentes, EventName = "TanuloGondviseloHelper.modGondviseloSave" });

            return PartialView(Constants.General.PopupView, pm);
        }

        public ActionResult NewGondviseloCim(int tanuloId)
        {
            var model = new CimElerhetosegModel()
            {
                FelhasznaloId = tanuloId,
                CimTipus = (int)CimTipusEnum.allando_lakcim,
                AlapertelmezettCim = true,
                IsGondviseloElerhetoseg = true,
                TanulovalEgyezik = false,
                FormSettings = new List<string>() {
                    CimElerhetosegConstant.CimSectionVisible,
                    CimElerhetosegConstant.IsNew,
                    CimElerhetosegConstant.AlapertelmezettCimVisible
                }
            };
            var pm = new PopUpModel(model, "_Elerhetoseg_Cim_BevitelGondv");

            var tanuloHelper = new TanuloHelper(ConnectionTypeExtensions.GetSessionConnectionType());
            if (!tanuloHelper.CheckLetezikGondviseloAllandoLakcim(tanuloId))
            {
                model.CimTipus = (int)CimTipusEnum.allando_lakcim;
            }

            model.GondviselokAlapertelmezettCimmel = tanuloHelper.GondviselokAlapertelmezettCimmel(tanuloId);

            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnElerhetosegCancel", Text = Resources.CommonResource.Megse, EventName = "GondviseloElerhetosegCimHelper.newGondviseloCimCancel" });
            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnElerhetosegOk", Text = Resources.CommonResource.Mentes, EventName = "GondviseloElerhetosegCimHelper.newGondviseloCimSave" });

            return PartialView(Constants.General.PopupView, pm);
        }

        public ActionResult ModGondviseloCim(int id)
        {
            var model = TanuloLogic.GetGondviseloElerhetosegCim(id);
            model.IsGondviseloElerhetoseg = true;
            model.FormSettings = new List<string>() {
                CimElerhetosegConstant.CimSectionVisible,
                CimElerhetosegConstant.AlapertelmezettCimVisible
            };
            var pm = new PopUpModel(model, "_Elerhetoseg_Cim_BevitelGondv");

            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnElerhetosegCancel", Text = Resources.CommonResource.Megse, EventName = "GondviseloElerhetosegCimHelper.modGondviseloCimCancel" });
            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnElerhetosegOk", Text = Resources.CommonResource.Mentes, EventName = "GondviseloElerhetosegCimHelper.modGondviseloCimSave" });

            return PartialView(Constants.General.PopupView, pm);
        }

        public ActionResult UjFelmentes(int tanuloId)
        {
            var model = new TanuloFelmentesModel();
            var pm = new PopUpModel(model, "_Felmentes_Bevitel");

            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnFelmentesCancel", Text = Resources.CommonResource.Megse, EventName = "TanuloFelmentesHelper.newFelmentesCancel" });
            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnFelmentesOk", Text = Resources.CommonResource.Mentes, EventName = "TanuloFelmentesHelper.newFelmentesSave" });

            return PartialView(Constants.General.PopupView, pm);
        }

        public ActionResult ModFelmentes(int id)
        {
            var model = TanuloLogic.GetFelmentes(id);
            var pm = new PopUpModel(model, "_Felmentes_Bevitel");

            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnFelmentesCancel", Text = Resources.CommonResource.Megse, EventName = "TanuloFelmentesHelper.modFelmentesCancel" });
            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnFelmentesOk", Text = Resources.CommonResource.Mentes, EventName = "TanuloFelmentesHelper.modFelmentesSave" });

            return PartialView(Constants.General.PopupView, pm);
        }

        public ActionResult OpenNewJogviszonyPopup(int TanuloId)
        {
            var model = new JogviszonyModel
            {
                IsNew = true,
                JogviszonyTipusaId = (int)TbJogviszonyTipusEnum.tanuloi_jogviszony,
                JogviszonyKeletkezesenekJogcimeId = (int)JogvKeletkezeseJogcimTipusEnum.felvetellel,
            };
            var pm = new PopUpModel(model, "_Jogviszony_Bevitel");

            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnJogviszonyCancel", Text = CommonResource.Megse, EventName = "JogviszonyHelper.newJogviszonyCancel" });
            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnJogviszonyMentes", Text = CommonResource.Mentes, EventName = "JogviszonyHelper.newJogviszonySave" });

            return PartialView(Constants.General.PopupView, pm);
        }

        public ActionResult OpenCloseJogviszonyPopup(JogviszonyModel model)
        {
            model.IsNew = false;
            var pm = new PopUpModel(model, "_Jogviszony_Bevitel");

            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnJogviszonyCancel", Text = CommonResource.Megse, EventName = "JogviszonyHelper.closeJogviszonyCancel" });
            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnJogviszonyMentes", Text = CommonResource.Mentes, EventName = "JogviszonyHelper.closeJogviszonySave" });

            return PartialView(Constants.General.PopupView, pm);
        }

        public ActionResult OpenSzakkepzesiMunkaszerzodes(SzakkepzesiMunkaszerzodesGridModel model)
        {
            var pm = new PopUpModel(model, "_SzakkepzesiMunkaszerzodes_Bevitel");

            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnSzakkepzesiMunkaszerzodesCancel", Text = CommonResource.Megse, EventName = "SzakkepzesiMunkaszerzodesHelper.Cancel" });
            pm.Buttons.Add(new ModalButtonModel() { Name = "BtnSzakkepzesiMunkaszerzodesMentes", Text = CommonResource.Mentes, EventName = $"SzakkepzesiMunkaszerzodesHelper.{(model.ID != null ? "Modify" : "Save")}" });

            return PartialView(Constants.General.PopupView, pm);
        }

        #endregion Popups

        #region Export

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.Dualis_Admin.ClaimValue, KretaClaimPackages.IsSzakiranyuOktatasertFelelos.ClaimValue)]
        public ActionResult TanuloExportBesorolashoz([FromUri] TanuloSearchModel data)
        {
            return TanuloLogic.TanuloExportBesorolashoz(data, OktNevelesiKategoriaEnum.NevelesOktatas);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.Dualis_Admin.ClaimValue, KretaClaimPackages.IsSzakiranyuOktatasertFelelos.ClaimValue)]
        public ActionResult TanulokLakcimmelExport([FromUri] TanuloSearchModel data)
        {
            return TanuloLogic.TanulokLakcimmelExport(data, OktNevelesiKategoriaEnum.NevelesOktatas);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.Dualis_Admin.ClaimValue, KretaClaimPackages.IsSzakiranyuOktatasertFelelos.ClaimValue)]
        public ActionResult TanulokTanugyiAdatiExport([FromUri] TanuloSearchModel model)
        {
            return TanuloLogic.ExportTanulokTanugyiAdatai(model);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.Dualis_Admin.ClaimValue, KretaClaimPackages.IsSzakiranyuOktatasertFelelos.ClaimValue)]
        public ActionResult ExportTanulokTantargyaiEsPedagogusai([FromUri] TanuloSearchModel data)
        {
            return TanuloLogic.ExportTanulokTantargyaiEsPedagogusai(data, OktNevelesiKategoriaEnum.NevelesOktatas);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.Dualis_Admin.ClaimValue, KretaClaimPackages.IsSzakiranyuOktatasertFelelos.ClaimValue)]
        public ActionResult GondviselokElerhetosegeiExport([FromUri] TanuloSearchModel data)
        {
            return TanuloLogic.ExportGondviselokElerhetosegei(data, OktNevelesiKategoriaEnum.NevelesOktatas);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.Dualis_Admin.ClaimValue, KretaClaimPackages.IsSzakiranyuOktatasertFelelos.ClaimValue)]
        public ActionResult TanuloKirStatExport([FromUri] TanuloSearchModel data)
        {
            data.ForOktober = true;
            return TanuloLogic.TanuloKirStatExport(data);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.Dualis_Admin.ClaimValue, KretaClaimPackages.IsSzakiranyuOktatasertFelelos.ClaimValue)]
        public ActionResult TanuloKirStatTeljesExport([FromUri] TanuloSearchModel data)
        {
            return TanuloLogic.TanuloKirStatExport(data);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.Dualis_Admin.ClaimValue, KretaClaimPackages.IsSzakiranyuOktatasertFelelos.ClaimValue)]
        public ActionResult TanuloSzirBeallitasokExport([FromUri] TanuloSearchModel data)
        {
            return TanuloLogic.TanuloSzirBeallitasokExport(data);
        }

        #endregion Export

        #region Belépési azonosító generálás

        [MvcRolePackageDenyAuthorize(KretaClaimPackages.IsSzirIntezmeny.ClaimValue)]
        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Adminisztrator.ClaimValue)]
        public ActionResult AzonositoGeneralasPopup(bool isTanulo, bool isPasswordReset, List<int> tanuloIdList = null, bool generaltFileLetoltes = true, bool emailKuldes = true)
        {
            var hozzaferesModel = new HozzaferesGeneralasaModel
            {
                TanuloIdList = tanuloIdList,
                IsTanulo = isTanulo,
                GeneraltFileLetoltes = generaltFileLetoltes,
                EmailKuldes = emailKuldes,
                IsPasswordReset = isPasswordReset
            };

            if (isPasswordReset)
            {
                hozzaferesModel.ConfirmText = isTanulo ?
                    TanuloResource.JelszoAlaphelyzetbeAllitasaTanuloConfirm :
                    TanuloResource.JelszoAlaphelyzetbeAllitasaGondviseloConfirm;
                if (isTanulo)
                {
                    hozzaferesModel.TanulokEmailElerhetosegNelkul = TanuloLogic.GetTanulokEmailNelkulSzam(tanuloIdList);
                }
            }
            else
            {
                if (tanuloIdList != null)
                {
                    hozzaferesModel.ConfirmText = isTanulo ?
                        TanuloResource.BelepesiAzonositoGeneralasaKijeloltTanulokConfirm :
                        TanuloResource.BelepesiAzonositoGeneralasaKijeloltTanulokGondviseloinekConfirm;
                }
                else
                {
                    hozzaferesModel.ConfirmText = isTanulo ?
                        TanuloResource.BelepesiAzonositoGeneralasTanuloConfirm :
                        TanuloResource.BelepesiAzonositoGeneralasGondviseloConfirm;
                }
            }
            var model = new PopUpModel(hozzaferesModel, "HozzaferesGeneralasModal");
            model.AddBtn(model, "hozzaferes_generalas_Nem", "Nem", "KretaWindowHelper.destroyAllWindow");
            model.AddBtn(model, "hozzaferes_generalas_Igen", "Igen", "TanuloHelper.hozzaferesGeneralas");
            return PartialView(Constants.General.PopupView, model);
        }

        [MvcRolePackageDenyAuthorize(KretaClaimPackages.IsSzirIntezmeny.ClaimValue)]
        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Adminisztrator.ClaimValue)]
        public JsonResult AzonositoGeneralas(bool isTanulo, bool fileLetoltesSzukseges, bool isPasswordReset, List<int> tanuloIdList = null, bool emailKuldesSzukseges = false, bool toroltFelhasznaloBelepes = false)
        {
            var popupModel = TanuloLogic.AzonositoGeneralas(isTanulo, fileLetoltesSzukseges, isPasswordReset, tanuloIdList, emailKuldesSzukseges, toroltFelhasznaloBelepes: toroltFelhasznaloBelepes);
            return Json(popupModel);
        }

        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.Osztalyfonok.ClaimValue)]
        public ActionResult SetGondviseloToBovitettPopup(List<int> tanuloIdList, bool isKijeloltTanulokGondviseloi)
        {
            if (isKijeloltTanulokGondviseloi && !TanuloLogic.ExistsGondviselo(tanuloIdList))
            {
                throw new StatusError(HttpStatusCode.BadRequest, ErrorResource.AKijeloltTanuloknakNincsGondiselojuk);
            }

            var hozzaferesModel = new GondviseloToBovitettModel
            {
                TanuloIdList = tanuloIdList,
                ConfirmText = isKijeloltTanulokGondviseloi ? TanuloResource.AKijeloltTanulokOsszesGondviselojenekBelepeseBovitettLeszBiztosanFolytatja : TanuloResource.AKivalasztottGondviselonekBovitettJogosultsagLeszGeneralvaBiztosanFolytatja,
                EmailKuldes = true,
                GeneraltFileLetoltes = true
            };

            var model = new PopUpModel(hozzaferesModel, "GondviseloToBovitettModal");
            model.AddBtn(model, "hozzaferes_generalas_Nem", CommonResource.Nem, "TanuloGondviseloHelper.setGondviseloToBovitettCancel");
            model.AddBtn(model, "hozzaferes_generalas_Igen", CommonResource.Igen, isKijeloltTanulokGondviseloi ? "TanuloHelper.setGondviseloToBovitett" : "TanuloGondviseloHelper.setGondviseloToBovitett");
            return PartialView(Constants.General.PopupView, model);
        }

        [MvcRolePackageDenyAuthorize(TanevEnum.Mind, KretaClaimPackages.IsSzirIntezmeny.ClaimValue)]
        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Adminisztrator.ClaimValue)]
        public JsonResult SetKijeloltTanulokGondviseloiToBovitett(bool emailKuldesSzukseges, bool fileLetoltesSzukseges, List<int> tanuloIdList)
        {
            var popupModel = TanuloLogic.SetKijeloltTanulokGondviseloiToBovitett(emailKuldesSzukseges, fileLetoltesSzukseges, tanuloIdList);
            return Json(popupModel);
        }

        [MvcRolePackageDenyAuthorize(TanevEnum.Mind, KretaClaimPackages.IsSzirIntezmeny.ClaimValue)]
        [MvcRolePackageAuthorize(TanevEnum.Mind, KretaClaimPackages.Adminisztrator.ClaimValue, KretaClaimPackages.Osztalyfonok.ClaimValue)]
        public JsonResult SetGondviseloToBovitett(bool emailKuldesSzukseges, bool fileLetoltesSzukseges, List<int> gondviseloIdList)
        {
            var popupModel = TanuloLogic.SetGondviseloToBovitett(emailKuldesSzukseges, fileLetoltesSzukseges, gondviseloIdList);
            return Json(popupModel);
        }

        public ActionResult DownloadEmailNelkuliTanulokJelszoResetEsetenXlsx(List<int> tanuloIds)
        {
            try
            {
                var nevmodel = new NyomtatvanyNevGeneralasModel { TanevID = ClaimData.AktivTanevID };
                var fileName = CommonExtensions.NevGeneralas(TanuloResource.TanulokEmailElerhetosegNelkulFileName, nevmodel);

                var fileContent = new TanuloHelper(ConnectionTypeExtensions.GetSessionConnectionType()).GetTanulokEmailNelkulJelszoResethezXlsx(tanuloIds);

                return new FileContentResult(fileContent, MediaTypeNames.Application.Octet)
                {
                    FileDownloadName = HttpUtility.UrlEncode($"{fileName}.xlsx", Encoding.UTF8),
                };
            }
            catch (Exception ex)
            {
                throw new StatusError(HttpStatusCode.BadRequest, ErrorResource.SikertelenAllomanyLetoltes, ex);
            }
        }

        #endregion Belépési azonosító generálás
    }
}
